@@ -221,7 +221,7 @@ impl SimpleLogger {
     ///
     /// This method is only available if the `colored` feature is enabled.
     #[must_use = "You must call init() to begin logging"]
-    #[cfg(feature = "chrono")]
+    #[cfg(feature = "colored")]
     pub fn with_colors(mut self, colors: bool) -> SimpleLogger {
         self.colors = colors;
         self
@@ -431,20 +431,16 @@ mod test {
 
         builder = builder.with_timestamps(false);
         assert!(builder.timestamps == false);
-
-        builder.init().unwrap();
     }
 
     #[test]
-    #[cfg(feature = "color")]
-    fn test_with_timestamps() {
+    #[cfg(feature = "colored")]
+    fn test_with_colors() {
         let mut builder = SimpleLogger::new();
-        assert!(builder.color == true);
+        assert!(builder.colors == true);
 
         builder = builder.with_colors(false);
-        assert!(builder.color == false);
-
-        builder.init().unwrap();
+        assert!(builder.colors == false);
     }
 
     fn create_log(name: &str, level: Level) -> Metadata {
